
create table podcasts (
    itunes_podcast_id text,
    artist_name text,
    collection_name text,
    score long,
    feed_url text,
    artwork_30_url text,
    artwork_60_url text,
    artwork_100_url text,
    artwork_600_url text,
    feed_artwork_url text,
    release_date text,
    country text,
    genre text,
    content_rating text,
    summary text,
    last_episode_time long,
    is_subscribed integer,
    language text,
    funding_url text,
    funding_cta text,
    persons_json text,
    location_json text,
    license_name text,
    license_url text,
    podcast_values_json text,
    pc20_guid text,
    podroll_json text
);

create unique index podcasts_ndx on podcasts(itunes_podcast_id);
create index pc20_guid_ndx on podcasts(pc20_guid);

create table episodes (
    id text not null primary key,
    guid text not null,
    itunes_podcast_id text,
    itunes_collection_name text,
    pub_date_unix long not null,
    title text,
    link text,
    comment text,
    description text,
    content_encoded text,
    media_url text,
    media_size text,
    media_type text,
    itunes_summary text,
    itunes_duration integer,
    deleted integer,
    favorited integer,
    flag_download integer,
    download_time integer,
    itunes_image text,
    itunes_subtitle text,
    transcript_url text,
    transcript_type text,
    chapters_url text,
    chapters_type text,
    soundbites_json text,
    persons_json text,
    location_json text,
    season_number real,
    season_title text,
    season_episode_number real,
    season_episode_title text,
    license_name text,
    license_url text,
    podcast_values_json text
);

create unique index episodes_ind on episodes(guid, itunes_podcast_id);
create index episodes_podcast_id_ind on episodes(itunes_podcast_id);

create table live_episodes (
    id text not null primary key,
    guid text not null,
    itunes_podcast_id text,
    itunes_collection_name text,
    pub_date_unix long,
    start_date_unix long,
    end_date_unix long,
    status text,
    title text,
    link text,
    comment text,
    description text,
    content_encoded text,
    media_url text,
    media_type text,
    itunes_summary text,
    deleted integer,
    itunes_image text,
    itunes_subtitle text,
    transcript_url text,
    transcript_type text,
    chapters_url text,
    chapters_type text,
    soundbites_json text,
    persons_json text,
    location_json text,
    season_number real,
    season_title text,
    season_episode_number real,
    season_episode_title text,
    license_name text,
    license_url text,
    chat_url text,
    content_links_json text,
    podcast_values_json text,
    live_values_json text
);

create unique index live_episodes_ind on live_episodes(guid, itunes_podcast_id);

create table episode_states (
    episode_id text not null primary key,
    playback_position integer,
    exhausted integer,
    position_update_time integer,
    exhausted_update_time integer,
    cloud_sync_time integer
);

create table playlists (
    id text not null primary key,
    name text,
    current_episode_id text,
    creation_date_unix long not null,
    cloud_sync_time integer,
    last_update_time integer,
    is_deleted integer,
    is_smart integer
);

create table playlist_episodes (
    id integer not null primary key,
    episode_id text not null,
    playlist_id text not null,
    episode_order integer not null,
    last_order_update_time integer,
    last_add_delete_time integer,
    cloud_sync_time integer,
    is_deleted integer
);

create index playlist_episodes_ind on playlist_episodes(playlist_id);

create table smart_playlist_podcasts (
    playlist_id text not null,
    itunes_podcast_id text not null,
    last_update_time integer,
    cloud_sync_time integer,
    is_deleted integer,
    primary key (playlist_id, itunes_podcast_id)
);

create table podcast_ratings (
    itunes_podcast_id text not null primary key,
    podchaser_podcast_id integer,
    rating real not null,
    user_rating real not null,
    rating_count integer not null,
    podchaser_url text,
    last_update_time integer not null
);

create table episode_ratings (
    episode_id text not null primary key,
    episode_podchaser_id integer,
    rating real not null,
    user_rating real not null,
    rating_count integer not null,
    podchaser_url text,
    last_update_time integer not null
);

create table podcast_tags (
    tag_name_lower text not null,
    tag_name text not null,
    itunes_podcast_id text not null,
    last_update_time integer,
    cloud_sync_time integer,
    is_deleted integer,
    primary key (tag_name_lower, itunes_podcast_id)
);

create table downloading (
    episode_id text not null primary key,
    is_auto_download integer not null,
    download_attempts integer default 0
);

create virtual table fts_episodes USING fts4 (content='episodes', itunes_collection_name, title, description);

-- start-statement

CREATE TRIGGER episodes_bu BEFORE UPDATE ON episodes BEGIN
  DELETE FROM fts_episodes WHERE docid=old.rowid;
END;

-- end-statement

-- start-statement

CREATE TRIGGER episodes_bd BEFORE DELETE ON episodes BEGIN
  DELETE FROM fts_episodes WHERE docid=old.rowid;
END;

-- end-statement

-- start-statement

CREATE TRIGGER episodes_au AFTER UPDATE ON episodes BEGIN
  INSERT INTO fts_episodes(docid, itunes_collection_name, title, description) VALUES(new.rowid, new.itunes_collection_name, new.title, new.description);
END;

-- end-statement

-- start-statement

CREATE TRIGGER episodes_ai AFTER INSERT ON episodes BEGIN
  INSERT INTO fts_episodes(docid, itunes_collection_name, title, description) VALUES(new.rowid, new.itunes_collection_name, new.title, new.description);
END;

-- end-statement

create table v4v_pending_stream_payments (
    episode_id text primary key,
    amount_to_send integer not null,
    last_update_time integer not null,
    playback_position integer
);

create table v4v_payment_log (
    id integer primary key,
    guid text,
    payment_time integer not null,
    amount integer not null,
    podcast_id text,
    podcast_title text,
    episode_id text,
    episode_title text,
    payment_request_details text not null,
    payment_response_details text,
    is_stream_payment integer not null,
    is_successful integer not null,
    is_time_split integer,
    payment_last_update_time integer,
    message text,
    playback_position integer
);

create unique index v4v_payment_log_guid_ind on v4v_payment_log(guid);

create table v4v_subpayment_log (
    id integer primary key,
    main_payment_guid text not null,
    payment_type text not null,
    amount integer not null,
    destination_name text,
    destination_addr text,
    payment_request_details text,
    payment_response_details text,
    error_message text,
    is_successful integer not null
);

create table stats_events (
    id text not null primary key,
    event_type text not null,
    event_time integer not null,
    assoc_value integer,
    itunes_podcast_id text,
    collection_name text,
    episode_id text,
    episode_title text
);

create index stats_events_event_type_ndx on stats_events(event_type);
create index stats_events_event_time_ndx on stats_events(event_time);
